.. _Buildbot Development:

Buildbot Development
====================

This chapter is the official repository for the collected wisdom of the Buildbot hackers.
It is intended both for developers writing patches that will be included in Buildbot itself, and for advanced users who wish to customize Buildbot.

.. toctree::
    :maxdepth: 2

    general
    apis
    py3-compat
    classes
